Learn R Programming

unigd (version 0.2.0)

ugd_close: Close unigd device.

Description

This achieves the same effect as grDevices::dev.off(), but will only close the device if it has the unigd type.

Usage

ugd_close(which = dev.cur(), all = FALSE)

Value

Number and name of the new active device (after the specified device has been shut down).

Arguments

which

Which device (ID).

all

Should all running unigd devices be closed.

Examples

Run this code
ugd()
hist(rnorm(100))
ugd_close() # Equvalent to dev.off()

ugd()
ugd()
ugd()
ugd_close(all = TRUE)

Run the code above in your browser using DataLab