powered by
Access general information of a unigd graphics device. This function will only work after starting a device with ugd().
ugd()
ugd_info(which = dev.cur())
List of status variables with the following named items: $id: Server unique ID, $version: unigd and library versions.
$id
$version
Which device (ID).
ugd() # Initialize graphics device ugd_info() # Get device information dev.off() # Close device
Run the code above in your browser using DataLab