Learn R Programming

unigd (version 0.2.0)

ugd_remove: Remove a unigd plot page.

Description

This function will only work after starting a device with ugd().

Usage

ugd_remove(page = 0, which = dev.cur())

Value

Whether the page existed (and thereby was successfully removed).

Arguments

page

Plot page to remove. If this is set to 0, the last page will be selected. Can be set to a numeric plot index or plot ID (see ugd_id()).

which

Which device (ID).

Examples

Run this code
ugd()
plot(1, 1) # page 1
hist(rnorm(100)) # page 2
ugd_remove(page = 1) # remove page 1

dev.off()

Run the code above in your browser using DataLab