Learn R Programming

unigd (version 0.2.0)

ugd_state: unigd device status.

Description

Access status information of a unigd graphics device. This function will only work after starting a device with ugd().

Usage

ugd_state(which = dev.cur())

Value

List of status variables with the following named items: $hsize: Plot history size (how many plots are accessible), $upid: Update ID (changes when the device has received new information), $active: Is the device the currently activated device.

Arguments

which

Which device (ID).

Examples

Run this code
ugd()
ugd_state()
plot(1, 1)
ugd_state()

dev.off()

Run the code above in your browser using DataLab