powered by
This function will only work after starting a device with ugd().
ugd()
ugd_remove(page = 0, which = dev.cur())
Whether the page existed (and thereby was successfully removed).
Plot page to remove. If this is set to 0, the last page will be selected. Can be set to a numeric plot index or plot ID (see ugd_id()).
0
ugd_id()
Which device (ID).
ugd() plot(1, 1) # page 1 hist(rnorm(100)) # page 2 ugd_remove(page = 1) # remove page 1 dev.off()
Run the code above in your browser using DataLab