powered by
See ugd_save() for saving rendered plots as files. This function will only work after starting a device with ugd().
ugd_save()
ugd()
ugd_render( page = 0, width = -1, height = -1, zoom = 1, as = "svg", which = dev.cur() )
Rendered plot. Text renderers return strings, binary renderers return byte arrays.
Plot page to render. If this is set to 0, the last page will be selected. Can be set to a numeric plot index or plot ID (see ugd_id()).
0
ugd_id()
Width of the plot. If this is set to -1, the last width will be selected.
-1
Height of the plot. If this is set to -1, the last height will be selected.
Zoom level. (For example: 2 corresponds to 200%, 0.5 would be 50%.)
2
0.5
Renderer.
Which device (ID).
ugd() plot(1, 1) ugd_render(width = 600, height = 400, as = "svg") dev.off()
Run the code above in your browser using DataLab