Access status information of a unigd graphics device.
This function will only work after starting a device with ugd().
Usage
ugd_state(which = dev.cur())
Value
List of status variables with the following named items:
$hsize: Plot history size (how many plots are accessible),
$upid: Update ID (changes when the device has received new information),
$active: Is the device the currently activated device.